import React, { createContext, useCallback, useEffect, useMemo, useState, } from 'react';
import AsyncStorage from '@react-native-async-storage/async-storage';
const RANDOM_KEY = '@koreanthinker/react-native-use-persisted-state';
export const PersistedStateContext = createContext({});
const PersistedStateProvider = ({ children }) => {
    const [loading, setLoading] = useState(true);
    const [storage, setStorage] = useState({});
    useEffect(() => {
        // First init
        (async () => {
            const value = await AsyncStorage.getItem(RANDOM_KEY);
            if (value) {
                setStorage(JSON.parse(value));
            }
            setLoading(false);
        })();
    }, []);
    useEffect(() => {
        // Storage state migrate to local storage
        AsyncStorage.setItem(RANDOM_KEY, JSON.stringify(storage));
    }, [storage]);
    const updateValue = useCallback((key, value) => {
        setStorage((prev) => {
            prev[key] = value;
            return prev;
        });
    }, []);
    const clearValue = useCallback((key) => {
        setStorage((prev) => {
            delete prev[key];
            return prev;
        });
    }, []);
    const value = useMemo(() => ({
        storage,
        updateValue,
        clearValue,
    }), [storage, updateValue, clearValue]);
    return (React.createElement(PersistedStateContext.Provider, { value: value }, loading ? null : children));
};
export default PersistedStateProvider;
