import { useCallback, useContext, useEffect, useMemo } from 'react';
import { PersistedStateContext } from './PersistedStateProvider';
const usePersistedState = (key, defaultValue) => {
    const { clearValue, storage, updateValue } = useContext(PersistedStateContext);
    useEffect(() => {
        if (typeof key !== 'string') {
            console.error(`Key type must be "string", Can not be ${typeof key}`);
        }
    }, [key]);
    const value = useMemo(() => {
        if (Object.keys(storage).includes(key)) {
            return storage[key];
        }
        return defaultValue;
    }, [storage, key, defaultValue]);
    const update = useCallback((newValue) => updateValue(key, newValue), []);
    const clear = useCallback(() => clearValue(key), [key]);
    return [value, update, clear];
};
export default usePersistedState;
